@@ -1,8 +1,8 @@
 # $File: //depot/cpan/Module-Install/lib/Module/Install.pm $ $Author: autrijus $
-# $Revision: #55 $ $Change: 1611 $ $DateTime: 2003/06/15 21:25:43 $ vim: expandtab shiftwidth=4
+# $Revision: #56 $ $Change: 1647 $ $DateTime: 2003/07/16 01:07:55 $ vim: expandtab shiftwidth=4
 
 package Module::Install;
-$VERSION = '0.21';
+$VERSION = '0.22';
 
 die <<END unless defined $INC{'inc/Module/Install.pm'};
 You must invoke Module::Install with:
@@ -27,8 +27,8 @@ Module::Install - Standalone, extensible Perl module installer
 
 =head1 VERSION
 
-This document describes version 0.21 of Module::Install, released
-June 16, 2003.
+This document describes version 0.22 of Module::Install, released
+July 16, 2003.
 
 =head1 SYNOPSIS
 
