@@ -1,21 +1,22 @@
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Admin/Manifest.pm $ $Author: autrijus $
+# $Revision: #17 $ $Change: 1515 $ $DateTime: 2003/05/15 11:09:47 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Admin::Manifest;
+use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.66_02';
+$VERSION = '0.01';
 
 use strict;
 use Cwd;
 use File::Spec;
 
 # XXX I really want this method in Module::Install::Admin::Makefile
-# But you can't call across Admin modules. Audrey??
+# But you can't call across Admin modules. Autrijus??
 sub dist_preop {
     my ($self, $distdir) = @_;
     return if $self->check_manifest;
 
-    print <<"END_MESSAGE";
+    print << "END";
 
 It appears that your MANIFEST does not contain the same components that
 are currently in the 'inc' directory. 
@@ -25,7 +26,7 @@ Please try running 'make manifest' and then run 'make dist' again.
 Remember to use the MANIFEST.SKIP file to control things that should not
 end up in your MANIFEST. See 'perldoc ExtUtils::Manifest' for details.
 
-END_MESSAGE
+END
     return if $self->prompt(
         'Do you *really* want to continue making a distribution?', 'n'
     ) =~ /^[Yy]/;
@@ -134,7 +135,7 @@ sub _find_files {
         my @files = ();
         local *DIR;
         opendir(DIR, $file) or die "Can't opendir $file";
-        while (defined(my $new_file = readdir(DIR))) {
+        while (my $new_file = readdir(DIR)) {
             next if $new_file =~ /^(\.|\.\.)$/;
             push @files, $self->_find_files($new_file, $file);
         }
@@ -149,9 +150,8 @@ __END__
 
 =head1 COPYRIGHT
 
-Copyright 2003, 2004 by
-Audrey Tang E<lt>autrijus@autrijus.orgE<gt>,
-Brian Ingerson E<lt>ingy@cpan.orgE<gt>
+Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
+Copyright 2003 by Brian Ingerson E<lt>ingy@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
