@@ -1,16 +1,13 @@
+# $File: //depot/cpan/Module-Install/lib/Module/Install/MakeMaker.pm $ $Author: autrijus $
+# $Revision: #10 $ $Change: 1645 $ $DateTime: 2003/07/16 01:05:06 $ vim: expandtab shiftwidth=4
+
 package Module::Install::MakeMaker;
+use Module::Install::Base; @ISA = qw(Module::Install::Base);
+
+$VERSION = '0.01';
 
-use strict;
-use Module::Install::Base;
 use ExtUtils::MakeMaker ();
 
-use vars qw{$VERSION $ISCORE @ISA};
-BEGIN {
-	$VERSION = '0.66_02';
-	$ISCORE  = 1;
-	@ISA     = qw{Module::Install::Base};
-}
-
 my $makefile;
 sub WriteMakefile {
     my ($self, %args) = @_;
@@ -23,15 +20,13 @@ sub WriteMakefile {
         $args{NAME} =~ s/::/-/g;
     }
 
-    foreach my $key (qw(name module_name version version_from abstract author installdirs)) {
+    foreach my $key (qw(name module_name version version_from abstract author)) {
         my $value = delete($args{uc($key)}) or next;
         $self->$key($value);
     }
 
     if (my $prereq = delete($args{PREREQ_PM})) {
-        while (my($k,$v) = each %$prereq) {
-            $self->requires($k,$v);
-        }
+        $self->requires($_ => $prereq->{$_}) for keys %$prereq;
     }
 
     # put the remaining args to makemaker_args
@@ -39,7 +34,7 @@ sub WriteMakefile {
 }
 
 END {
-    if ( $makefile ) {
+    if ($makefile) {
         $makefile->write;
         $makefile->Meta->write;
     }
